## Preseed Configurator - A graphical preseed file generator
## Copyright (C) 2009 Oriol Matavacas Rodriguez
## Based on GPL project "Kickstart Configurator v2.5" from RedHat,Brent Fox and Tammy Fox


## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.


import gtk
import gtk.glade
import gobject
import string
import os
import random
import crypt
import getopt
import shlex

import kickstartGui

##
## I18N
##
import gettext
domain = 'system-config-kickstart'
gettext.bindtextdomain(domain, '/usr/share/locale')
gettext.textdomain(domain)
_ = gettext.gettext
gtk.glade.bindtextdomain(domain)

class additional:
    def __init__(self, parent_class, xml, notebook, kickstartData):
        self.parent_class = parent_class
        self.notebook = notebook
        self.kickstartData = kickstartData
        self.xml = xml

        self.eject_checkbutton = xml.get_widget("eject_checkbutton")
        self.MKShutdown_checkbutton = xml.get_widget("MKShutdown_checkbutton")
        self.reboot_checkbutton = xml.get_widget("reboot_checkbutton")
        self.text_install_checkbutton = xml.get_widget("text_install_checkbutton")
        self.interactive_checkbutton = xml.get_widget("interactive_checkbutton")
        self.media_check = xml.get_widget("media_check")
        self.next_cd_button = xml.get_widget("next_cd_button")
        self.popularity_contest = xml.get_widget("popularity_contest")
        self.oem_mode = xml.get_widget("oem_mode")
        self.oem_mode.connect("toggled",parent_class.OEMToggled)
# NTP clock buttons
        self.ntp_checkbutton = xml.get_widget("ntp_checkbutton")
        self.ntp_entry = xml.get_widget("ntp_entry")
        self.ntp_checkbutton.connect("toggled",self.toggle_ntp)
        self.ntp_entry.set_sensitive(False)
# Default options
        try:
            self.eject_checkbutton.set_active(True)
            self.interactive_checkbutton.set_active(False)
# For future imprementation. This options need be a kernel parameter
            self.text_install_checkbutton.hide()
            self.interactive_checkbutton.hide()
        except:
            pass

    def toggle_ntp(self,args):
        self.ntp_entry.set_sensitive(self.ntp_checkbutton.get_active())



    def getData (self):

        if self.eject_checkbutton.get_active():
            self.kickstartData.setEject("eject")
        else:
            self.kickstartData.setEject(None)

        if self.MKShutdown_checkbutton.get_active():
            self.kickstartData.setMKShutdown("MKShutdown")
        else:
            self.kickstartData.setMKShutdown(None)

        if self.reboot_checkbutton.get_active():
            self.kickstartData.setReboot("reboot")
        else:
            self.kickstartData.setReboot(None)

        if self.text_install_checkbutton.get_active():
            self.kickstartData.setText("text")
        else:
            self.kickstartData.setText(None)

        if self.interactive_checkbutton.get_active():
            self.kickstartData.setInteractive("interactive")
        else:
            self.kickstartData.setInteractive(None)

        if self.media_check.get_active():
            self.kickstartData.setCheck("check")
        else:
            self.kickstartData.setCheck(None)

        if self.next_cd_button.get_active():
            self.kickstartData.setNextCD("nextcd")
        else:
            self.kickstartData.setNextCD(None)

# NTP Synchronize
        buf_ntp = [""]
        if self.ntp_checkbutton.get_active():
            buf_ntp.extend(["d-i clock-setup/ntp boolean true" + \
                        "\nd-i clock-setup/ntp-server string " + \
                        self.ntp_entry.get_text() + "\n"])
#            buf_ntp = buf_ntp + "\nd-i clock-setup/ntp boolean true" + \
#                        "\nd-i clock-setup/ntp-server string " + \
#                        self.ntp_entry.get_text() + "\n"
        self.kickstartData.setNTP(buf_ntp)

        buf_popularity = [""]
        if self.popularity_contest.get_active():
            buf_popularity.extend(["popularity-contest popularity-contest/participate boolean true"])
        else:
            buf_popularity.extend(["popularity-contest popularity-contest/participate boolean false"])
        self.kickstartData.setPopularity(buf_popularity)


        buf = ""
        if self.oem_mode.get_active():
            buf = buf + "#OEM Configuration" + \
                        "\nd-i oem-config/enable boolean true"
            self.kickstartData.setOEM("OEM")

        self.kickstartData.setadditional(buf)
        return 0


    def fillData(self):
        list = self.kickstartData.additional()
