## Preseed Configurator - A graphical preseed file generator
## Copyright (C) 2009 Oriol Matavacas Rodriguez
## Based on GPL project "Kickstart Configurator v2.5" from RedHat,Brent Fox and Tammy Fox

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.


import gtk
import gtk.glade
import gobject
import string
import os
import random
import crypt
import getopt
import shlex


from hardwareLists import langDict, layoutDict, variantDict

import kickstartGui

##
## I18N
##
import gettext
domain = 'system-config-kickstart'
gettext.bindtextdomain(domain, '/usr/share/locale')
gettext.textdomain(domain)
_ = gettext.gettext
gtk.glade.bindtextdomain(domain)

class basic:

    def __init__(self, parent_class, xml, notebook, kickstartData):
        self.parent_class = parent_class
        self.notebook = notebook
        self.kickstartData = kickstartData
        self.xml = xml

        self.lang_combo = xml.get_widget("lang_combo")
        self.keyboard_combo = xml.get_widget("keyboard_combo")

        self.timezone_combo = xml.get_widget("timezone_combo")
        self.utc_check_button = xml.get_widget("utc_check_button")

        self.root_enable_checkbutton = xml.get_widget("root_enable_checkbutton")
        self.root_passwd_entry = xml.get_widget("root_passwd_entry")
        self.root_passwd_confirm_entry = xml.get_widget("root_passwd_confirm_entry")
        self.user_create_checkbutton = xml.get_widget("user_create_checkbutton")
        self.user_fullname_entry = xml.get_widget("user_fullname_entry")
        self.user_name_entry = xml.get_widget("user_name_entry")
        self.user_passwd_entry = xml.get_widget("user_passwd_entry")
        self.user_passwd_confirm_entry = xml.get_widget("user_passwd_confirm_entry")
        self.lang_support_view = xml.get_widget("lang_support_view")
        self.encrypt_root_pw_checkbutton = xml.get_widget("encrypt_root_pw_checkbutton")
        self.encrypt_user_pw_checkbutton = xml.get_widget("encrypt_user_pw_checkbutton")
        self.lang_support_list = xml.get_widget("lang_support_list")
        self.platform_combo = xml.get_widget("platform_combo")
        self.use_md5hash = xml.get_widget("use_md5hash")
        self.use_shadow = xml.get_widget("use_shadow")
# Default users UID GRUPS
        self.uid_grub_table = xml.get_widget("uid_grub_table")
        self.UID_checkbutton = xml.get_widget("UID_checkbutton")
        self.UID_entry = xml.get_widget("UID_entry")
        self.grups_checkbutton = xml.get_widget("grups_checkbutton")
        self.grups_entry = xml.get_widget("grups_entry")
# OEM Mode
        self.user_vbox = xml.get_widget("user_vbox")
        self.label217 = xml.get_widget("label217")
        self.oem_mode = xml.get_widget("oem_mode")
# Hostname and domain
        self.hostname_checkbutton = xml.get_widget("hostname_checkbutton")
        self.hostname_entry = xml.get_widget("hostname_entry")
        self.domain_checkbutton = xml.get_widget("domain_checkbutton")
        self.domain_entry = xml.get_widget("domain_entry")

        self.platform_list = [_("x86"), _("PowerPC"), _("AMD64 or Intel EM64T"), _("IA-64"), _("SPARC")]
        self.platform_combo.set_popdown_strings(self.platform_list)
        self.platform_combo.entry.connect("changed", self.platformChanged)

        self.root_enable_checkbutton.connect("toggled", self.rootEnableToggled)
#        self.root_passwd_entry.set_sensitive(False)
#        self.root_passwd_confirm_entry.set_sensitive(False)
#        self.encrypt_root_pw_checkbutton.set_sensitive(False)
#        self.user_create_checkbutton.set_sensitive(False)

        self.user_create_checkbutton.connect("toggled", self.userCreateToggled)

        self.lang_support_store = gtk.ListStore(gobject.TYPE_BOOLEAN, gobject.TYPE_STRING)
        self.lang_support_view.set_model(self.lang_support_store)
        self.checkbox = gtk.CellRendererToggle()
        col = gtk.TreeViewColumn('', self.checkbox, active = 0)
        col.set_fixed_width(20)
        col.set_clickable(True)
        self.checkbox.connect("toggled", self.langToggled)
        self.lang_support_view.append_column(col)

        col = gtk.TreeViewColumn("", gtk.CellRendererText(), text=1)
        self.lang_support_view.append_column(col)

        self.langDict = langDict


        #populate language combo
        self.lang_list = self.langDict.keys()
        self.lang_list.sort()
        self.lang_combo.set_popdown_strings(self.lang_list)

        #set default to English
        self.lang_combo.list.select_item(self.lang_list.index('English (United States)'))

        self.populateLangSupport()
#        for lang in lang_list:
#            self.lang_support_list.append([lang])



        #populate keyboard combo
        self.keyboard_dict = {}
        for layoutname, layoutcode in layoutDict.iteritems():
            # TODO: internationalisation
            self.keyboard_dict[layoutname] = layoutcode
            for variantname, variantcode in variantDict[layoutcode].iteritems():
                if variantcode:
                    code = '%s_%s' % (layoutcode, variantcode)
                    self.keyboard_dict[variantname] = code

        keys = self.keyboard_dict.keys()
        keys.sort()
        keyboard_list = []

        for item in keys:
            keyboard_list.append(item)

#keyboard_list = ['American English ', 'British English ', 'Spanish ', 'French ', 'German ', 'Italian ', 'Russian ', 'Belarusian ', 'Belgian ', 'Brazilian (ABNT2 layout) ', 'Brazilian (EUA Layout) ', 'Bulgarian ', 'Canadian French ', 'Croatian ', 'Czech ', 'Danish ', 'Dutch ', 'Dvorak ', 'Estonian ', 'Finnish ', 'Greek ', 'Hebrew ', 'Hungarian ', 'Icelandic ', 'Japanese ', 'Latin American ', 'Latvian ', 'Lithuanian ', 'Macedonian ', 'Norwegian ', 'Polish ', 'Portuguese ', 'Romanian ', 'Serbian (Cyrillic) ', 'Slovakian ', 'Slovene ', 'Swedish ', 'Swiss French ', 'Swiss German ', 'Turkish (F layout) ', 'Turkish (Q layout) ', 'Ukranian']
#keyboard_dict = {'American English ': 'us', 'British English': 'uk', 'Spanish ': 'es', 'French ': 'fr-latin9', 'German ': 'de-latin1-nodeadkeys', 'Italian ': 'it', 'Russian ': 'ru', 'Belarusian ': 'by', 'Belgian ': 'be2-latin1', 'Brazilian (ABNT2 layout) ': 'br-abnt2', 'Brazilian (EUA Layout) ': 'br-latin1', 'Bulgarian ': 'bg', 'Canadian French ': 'cf', 'Croatian ': 'croat', 'Czech ': 'cz-lat2', 'Danish ': 'dk-latin1', 'Dutch ': 'nl', 'Dvorak ': 'dvorak' , 'Estonian ': 'et', 'Finnish ': 'fi-latin1', 'Greek ': 'gr', 'Hebrew ': 'hebrew', 'Hungarian ': 'hu' , 'Icelandic ': 'is-latin1', 'Japanese ': 'jp106', 'Latin American ' : 'la-latin1', 'Latvian ': 'lv-latin4', 'Lithuanian ': 'lt', 'Macedonian ': 'mk', 'Norwegian ': 'no-latin1', 'Polish ': 'pl', 'Portuguese ': 'pt-latin1', 'Romanian ': 'ro', 'Serbian (Cyrillic) ': 'sr-cy', 'Slovakian ': 'sk-qwerty', 'Slovene ': 'slovene', 'Swedish ': 'se-latin1', 'Swiss French ' : 'fr_CH-latin1', 'Swiss German ': 'sg-latin1', 'Turkish (F layout) ': 'trfu', 'Turkish (Q layout) ': 'trqu', 'Ukranian' : 'ua'}



        self.keyboard_combo.set_popdown_strings(keyboard_list)

        # TODO: fill with current keymap; for now, default to U.S. English
	#set keyboard to current keymap
        for layoutname, layoutcode in layoutDict.iteritems():
            if layoutcode == 'us':
                self.keyboard_combo.entry.set_text(layoutname)
                break



        #populate time zone combo
        if os.access("/usr/share/zoneinfo/zone.tab", os.R_OK):
            tz = open ("/usr/share/zoneinfo/zone.tab", "r")
            lines = tz.readlines()
            tz.close()

        self.timezone_list = []

        try:
            for line in lines:
                if line[:1] == "#":
                    pass
                else:
                    tokens = string.split(line)
                    self.timezone_list.append(tokens[2])

            self.timezone_list.sort()
        except:
            self.timezone_list = []

        try:
            select = self.timezone_list.index("Europe/London")
        except:
            select = 0

        self.timezone_combo.set_popdown_strings(self.timezone_list)
        self.timezone_combo.list.select_item(select)
        self.oem_mode.connect("toggled",parent_class.OEMToggled)
        self.grups_entry.connect("changed", self.GRUPSentryChanged)
        self.UID_entry.connect("changed", self.UIDentryChanged)
        self.hostname_entry.connect("changed",self.HostnameChanged)
        self.domain_entry.connect("changed",self.DomainChanged)

#Default options
        self.root_enable_checkbutton.set_active(True)
        self.use_md5hash.set_active(True)
        self.use_shadow.set_active(True)

    def HostnameChanged(self,entry):
        self.hostname_checkbutton.set_active(True)

    def DomainChanged(self,entry):
        self.domain_checkbutton.set_active(True)

    def UIDentryChanged(self,entry):
        if self.UID_entry.get_text() != "":
            self.UID_checkbutton.set_active(True)

    def GRUPSentryChanged(self,entry):
        if self.grups_entry.get_text() != "":
            self.grups_checkbutton.set_active(True)

    def OEMToggled(self):
        if self.oem_mode.get_active():
            self.user_vbox.hide()
            self.label217.set_text(_("OEM Mode enabled, a oem temporally user will be configured"))
            self.label217.show()
        else:
            self.label217.set_text(_("User Configuration"))
            self.user_vbox.show()
            self.label217.show()

    def langToggled(self, data, row):
        iter = self.lang_support_store.get_iter((int(row),))
        val = self.lang_support_store.get_value(iter, 0)
        self.lang_support_store.set_value(iter, 0 , not val)

    def rootEnableToggled(self, args):
        status = self.root_enable_checkbutton.get_active()
        self.root_passwd_entry.set_sensitive(status)
        self.root_passwd_confirm_entry.set_sensitive(status)
        self.encrypt_root_pw_checkbutton.set_sensitive(status)
        if not status:
            self.user_create_checkbutton.set_active(True)

    def userCreateToggled(self, args):
        status = self.user_create_checkbutton.get_active()
        self.user_fullname_entry.set_sensitive(status)
        self.user_name_entry.set_sensitive(status)
        self.user_passwd_entry.set_sensitive(status)
        self.user_passwd_confirm_entry.set_sensitive(status)
        self.encrypt_user_pw_checkbutton.set_sensitive(status)
        self.uid_grub_table.set_sensitive(status)
        if not status:
            self.root_enable_checkbutton.set_active(True)

    def getData(self, doInstall):
        lang = self.languageLookup(self.lang_combo.entry.get_text())
        self.kickstartData.setLang([self.languageLookup(self.lang_combo.entry.get_text())])

        lang_list = []
        iter = self.lang_support_store.get_iter_first()

        while iter:
            if self.lang_support_store.get_value(iter, 0) == True:
                lang = self.lang_support_store.get_value(iter, 1)
                lang_list.append(self.langDict[lang])

            iter = self.lang_support_store.iter_next(iter)

        defaultLang = self.languageLookup(self.lang_combo.entry.get_text())

        self.kickstartData.setLangSupport(lang_list)
        self.kickstartData.setDefaultLang(defaultLang)

        keys = self.keyboard_dict.keys()
        keys.sort()
        for item in keys:
            if item == self.keyboard_combo.entry.get_text():
                self.kickstartData.setKeyboard([self.keyboard_dict[item]])
                break



        if self.utc_check_button.get_active():
            self.kickstartData.setTimezone(["d-i clock-setup/utc boolean true\nd-i time/zone string %s" % self.timezone_combo.entry.get_text()])
        else:
            self.kickstartData.setTimezone(["d-i clock-setup/utc boolean false\nd-i time/zone string %s" % self.timezone_combo.entry.get_text()])

        if self.root_enable_checkbutton.get_active() == True and self.oem_mode.get_active() == False:
            if self.root_passwd_entry.get_text() != self.root_passwd_confirm_entry.get_text():
                dlg = gtk.MessageDialog(None, 0, gtk.MESSAGE_ERROR, gtk.BUTTONS_OK, _("Root passwords do not match."))
                dlg.set_title(_("Error"))
                dlg.set_default_size(100, 100)
                dlg.set_position (gtk.WIN_POS_CENTER)
                dlg.set_icon(kickstartGui.iconPixbuf)
                dlg.set_border_width(2)
                dlg.set_modal(True)
                toplevel = self.xml.get_widget("main_window")
                dlg.set_transient_for(toplevel)
                dlg.run()
                dlg.hide()
                self.notebook.set_current_page(4)
                self.root_passwd_entry.set_text("")
                self.root_passwd_confirm_entry.set_text("")
                self.root_passwd_entry.grab_focus()
                return None

            if self.root_passwd_entry.get_text() == "" and doInstall:
                dlg = gtk.MessageDialog(None, 0, gtk.MESSAGE_ERROR, gtk.BUTTONS_OK, _("Please select a root password."))
                dlg.set_title(_("Error"))
                dlg.set_default_size(100, 100)
                dlg.set_position (gtk.WIN_POS_CENTER)
                dlg.set_icon(kickstartGui.iconPixbuf)
                dlg.set_border_width(2)
                dlg.set_modal(True)
                toplevel = self.xml.get_widget("main_window")
                dlg.set_transient_for(toplevel)
                dlg.run()
                dlg.hide()
                self.notebook.set_current_page(4)
                self.root_passwd_entry.grab_focus()
                return None

            if self.encrypt_root_pw_checkbutton.get_active() == True:
                pure = self.root_passwd_entry.get_text()

                salt = "$1$"
                saltLen = 8

                if not pure.startswith(salt):
                    for i in range(saltLen):
                        salt = salt + random.choice (string.letters + string.digits + './')

                    self.passwd = crypt.crypt (pure, salt)

                    temp = unicode (self.passwd, 'iso-8859-1')
                    self.kickstartData.setRootPw(["-crypted password " + temp])
                else:
                    self.kickstartData.setRootPw(["-crypted password " + pure])

            else:
                self.passwd = self.root_passwd_entry.get_text()
                self.kickstartData.setRootPw([' password '+ self.passwd, '\nd-i passwd/root-password-again password '+ self.passwd])

        else:
            self.kickstartData.setRootPw(None)


        if self.user_create_checkbutton.get_active() == True and self.oem_mode.get_active() == False:
            if self.user_name_entry.get_text() == "":
                dlg = gtk.MessageDialog(None, 0, gtk.MESSAGE_ERROR, gtk.BUTTONS_OK, _("Please select a username."))
                dlg.set_title(_("Error"))
                dlg.set_default_size(100, 100)
                dlg.set_position (gtk.WIN_POS_CENTER)
                dlg.set_icon(kickstartGui.iconPixbuf)
                dlg.set_border_width(2)
                dlg.set_modal(True)
                toplevel = self.xml.get_widget("main_window")
                dlg.set_transient_for(toplevel)
                dlg.run()
                dlg.hide()
                self.notebook.set_current_page(4)
                self.user_name_entry.grab_focus()
                return None

            if ":" in self.user_name_entry.get_text():
                dlg = gtk.MessageDialog(None, 0, gtk.MESSAGE_ERROR, gtk.BUTTONS_OK, _("Username cannot contain \":\" special caracter"))
                dlg.set_title(_("Error"))
                dlg.set_default_size(100, 100)
                dlg.set_position (gtk.WIN_POS_CENTER)
                dlg.set_icon(kickstartGui.iconPixbuf)
                dlg.set_border_width(2)
                dlg.set_modal(True)
                toplevel = self.xml.get_widget("main_window")
                dlg.set_transient_for(toplevel)
                dlg.run()
                dlg.hide()
                self.notebook.set_current_page(4)
                self.user_name_entry.grab_focus()
                return None

            if ":" in self.user_fullname_entry.get_text():
                dlg = gtk.MessageDialog(None, 0, gtk.MESSAGE_ERROR, gtk.BUTTONS_OK, _("Full Name cannot contain \":\" special caracter"))
                dlg.set_title(_("Error"))
                dlg.set_default_size(100, 100)
                dlg.set_position (gtk.WIN_POS_CENTER)
                dlg.set_icon(kickstartGui.iconPixbuf)
                dlg.set_border_width(2)
                dlg.set_modal(True)
                toplevel = self.xml.get_widget("main_window")
                dlg.set_transient_for(toplevel)
                dlg.run()
                dlg.hide()
                self.notebook.set_current_page(4)
                self.user_fullname_entry.grab_focus()
                return None

            if self.user_passwd_entry.get_text() != self.user_passwd_confirm_entry.get_text():
                dlg = gtk.MessageDialog(None, 0, gtk.MESSAGE_ERROR, gtk.BUTTONS_OK, _("User passwords do not match."))
                dlg.set_title(_("Error"))
                dlg.set_default_size(100, 100)
                dlg.set_position (gtk.WIN_POS_CENTER)
                dlg.set_icon(kickstartGui.iconPixbuf)
                dlg.set_border_width(2)
                dlg.set_modal(True)
                toplevel = self.xml.get_widget("main_window")
                dlg.set_transient_for(toplevel)
                dlg.run()
                dlg.hide()
                self.notebook.set_current_page(4)
                self.user_passwd_entry.set_text("")
                self.user_passwd_confirm_entry.set_text("")
                self.user_passwd_entry.grab_focus()
                return None

            if self.user_passwd_entry.get_text() == "":
                dlg = gtk.MessageDialog(None, 0, gtk.MESSAGE_ERROR, gtk.BUTTONS_OK, _("Please select a user password."))
                dlg.set_title(_("Error"))
                dlg.set_default_size(100, 100)
                dlg.set_position (gtk.WIN_POS_CENTER)
                dlg.set_icon(kickstartGui.iconPixbuf)
                dlg.set_border_width(2)
                dlg.set_modal(True)
                toplevel = self.xml.get_widget("main_window")
                dlg.set_transient_for(toplevel)
                dlg.run()
                dlg.hide()
                self.notebook.set_current_page(4)
                self.user_passwd_entry.grab_focus()
                return None

            if self.UID_checkbutton.get_active() and not (self.UID_entry.get_text()).isdigit():
                    dlg = gtk.MessageDialog(None, 0, gtk.MESSAGE_ERROR, gtk.BUTTONS_OK, _("User UID may be a number value"))
                    dlg.set_title(_("Error"))
                    dlg.set_default_size(100, 100)
                    dlg.set_position (gtk.WIN_POS_CENTER)
                    dlg.set_icon(kickstartGui.iconPixbuf)
                    dlg.set_border_width(2)
                    dlg.set_modal(True)
                    toplevel = self.xml.get_widget("main_window")
                    dlg.set_transient_for(toplevel)
                    dlg.run()
                    dlg.hide()
                    self.notebook.set_current_page(4)
                    self.UID_entry.grab_focus()
                    return None

            user_args = ["d-i passwd/user-fullname string", \
                         self.user_fullname_entry.get_text().replace('"', '\\"'),\
                         '\nd-i passwd/username string ',self.user_name_entry.get_text()]
            if self.encrypt_user_pw_checkbutton.get_active() == True:
                pure = self.user_passwd_entry.get_text()

                salt = "$1$"
                saltLen = 8

                if not pure.startswith(salt):
                    for i in range(saltLen):
                        salt = salt + random.choice (string.letters + string.digits + './')

                    self.passwd = crypt.crypt (pure, salt)

                    temp = unicode (self.passwd, 'iso-8859-1')
                    user_args.extend(["\nd-i passwd/user-password-crypted password", temp])
                else:
                    user_args.extend(["\nd-i passwd/user-password-crypted password", pure])

            else:
                self.passwd = self.user_passwd_entry.get_text()
                user_args.extend(["\nd-i passwd/user-password password insecure", self.passwd])
                user_args.extend(["\nd-i passwd/user-password-again password insecure", self.passwd])

            if self.UID_checkbutton.get_active():
                user_args.extend(["\nd-i passwd/user-uid string ", self.UID_entry.get_text()])

            if self.grups_checkbutton.get_active():
                user_args.extend(["\nd-i passwd/user-default-groups ",self.grups_entry.get_text()])


            self.kickstartData.setUser(user_args)

        else:
            self.kickstartData.setUser(None)

###########
# MaTa
        user_opts = [""]
        if self.use_md5hash.get_active() == False:
            user_opts.extend(["\nd-i passwd/md5 boolean false"])
        if self.use_shadow.get_active() == False:
            user_opts.extend(["\nd-i passwd/shadow boolean false"])

        self.kickstartData.setUserOpts(user_opts)

        host_dom = [""]
        if self.hostname_checkbutton.get_active():
            host_dom.extend(["d-i netcfg/get_hostname string " + self.hostname_entry.get_text() + "\n"])
        else:
            host_dom.extend(["d-i netcfg/get_hostname string unassigned-hostname\n"])


        if self.domain_checkbutton.get_active():
            host_dom.extend(["d-i netcfg/get_domain string " + self.domain_entry.get_text()])
        else:
            host_dom.extend(["d-i netcfg/get_domain string unassigned-domain"])


        self.kickstartData.sethost_dom(host_dom)

        self.kickstartData.setPlatform(self.platform_combo.entry.get_text())
        return 0

    def languageLookup(self, args):
        return self.langDict [args]

    def populateLangSupport(self):
        for lang in self.lang_list:
            iter = self.lang_support_store.append()
            self.lang_support_store.set_value(iter, 0, False)
            self.lang_support_store.set_value(iter, 1, lang)

    def platformChanged(self, entry):
        platform = entry.get_text()
        if platform:
            self.parent_class.platformTypeChanged(entry.get_text())

    def fillData(self):
        #set platform
        if self.kickstartData.getPlatform() in self.platform_list:
            self.platform_combo.entry.set_text(self.kickstartData.getPlatform())

        #set language
        for lang in self.langDict.keys():
            if self.langDict[lang] == self.kickstartData.getLang():
                self.lang_combo.list.select_item(self.lang_list.index(lang))

        #set keyboard
        for keyboardname, keyboardcode in self.keyboard_dict.iteritems():
            if keyboardcode == self.kickstartData.getKeyboard():
                self.keyboard_combo.entry.set_text(keyboardname)




        #set timezone
        self.timezone_combo.list.select_item(self.timezone_list.index(self.kickstartData.getTimezone()))

        #set the supported lang list
        langSupportList = self.kickstartData.getLangSupport()

        if langSupportList == []:
            iter = self.lang_support_store.get_iter_root()
            while iter:
                self.lang_support_store.set_value(iter, 0, True)
                iter = self.lang_support_store.iter_next(iter)
        else:
            langSupportList.append(self.kickstartData.getDefaultLang())

            iter = self.lang_support_store.get_iter_root()

            while iter:
                if self.langDict[self.lang_support_store.get_value(iter, 1)] in langSupportList:
                    self.lang_support_store.set_value(iter, 0, True)
                iter = self.lang_support_store.iter_next(iter)


        if self.kickstartData.getReboot():
            self.reboot_checkbutton.set_active(True)

        if self.kickstartData.getText():
            self.text_install_checkbutton.set_active(True)

        if self.kickstartData.getInteractive():
            self.interactive_checkbutton.set_active(True)

        if self.kickstartData.getRootPw():
            self.root_enable_checkbutton.set_active(True)
            self.encrypt_root_pw_checkbutton.set_active(False)
            line = self.kickstartData.getRootPw()
            (opts, args) = getopt.getopt(line.split(), "", ["disabled", "iscrypted"])

            for opt, value in opts:
                if opt == "--disabled":
                    self.root_enable_checkbutton.set_active(False)
                elif opt == "--iscrypted":
                    self.encrypt_root_pw_checkbutton.set_active(True)

            if self.root_enable_checkbutton.get_active():
                self.root_passwd_entry.set_text(args[0])
                self.root_passwd_confirm_entry.set_text(args[0])
            else:
                self.root_passwd_entry.set_text('')
                self.root_passwd_confirm_entry.set_text('')

        if self.kickstartData.getUser():
            self.user_create_checkbutton.set_active(True)
            self.encrypt_user_pw_checkbutton.set_active(False)
            line = self.kickstartData.getUser()
            user_password = ''
            (opts, args) = getopt.gnu_getopt(shlex.split(line), "", ["disabled", "fullname=", "iscrypted", "password="])

            for opt, value in opts:
                if opt == "--disabled":
                    self.user_create_checkbutton.set_active(False)
                elif opt == "--fullname":
                    self.user_fullname_entry.set_text(value)
                elif opt == "--iscrypted":
                    self.encrypt_user_pw_checkbutton.set_active(True)
                elif opt == "--password":
                    user_password = value

            if self.user_create_checkbutton.get_active():
                self.user_name_entry.set_text(args[0])
                self.user_passwd_entry.set_text(user_password)
                self.user_passwd_confirm_entry.set_text(user_password)
            else:
                self.user_name_entry.set_text('')
                self.user_passwd_entry.set_text('')
                self.user_passwd_confirm_entry.set_text('')

