## Preseed Configurator - A graphical preseed file generator
## Copyright (C) 2009 Oriol Matavacas Rodriguez
## Based on GPL project "Kickstart Configurator v2.5" from RedHat,Brent Fox and Tammy Fox

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

import gtk
import gtk.glade
import string
import random
import crypt


##
## I18N
##
import gettext
domain = 'system-config-kickstart'
gettext.bindtextdomain(domain, '/usr/share/locale')
gettext.textdomain(domain)
_ = gettext.gettext
gtk.glade.bindtextdomain(domain)

import kickstartGui

class bootloader:

    def __init__(self, xml, notebook, kickstartData):
        self.kickstartData = kickstartData
        self.notebook = notebook
        self.xml = xml
        self.bootloader_vbox = xml.get_widget("bootloader_vbox")
        self.bootloader_label = xml.get_widget("bootloader_label")

        self.no_bootloader_radio = xml.get_widget("no_bootloader_radio")
        self.lilo_radiobutton = xml.get_widget("lilo_radiobutton")
        self.upgrade_bootloader_radio = xml.get_widget("upgrade_bootloader_radio")
        self.grub_mbr_radiobutton = xml.get_widget("grub_mbr_radiobutton")
        self.firstsector_radiobutton = xml.get_widget("firstsector_radiobutton")

## i aix
#        self.parameters_label = xml.get_widget("parameters_label")
#### Aixo si
#        self.parameters_entry = xml.get_widget("parameters_entry")


#no?
        self.linear_checkbutton = xml.get_widget("linear_checkbutton")
        self.lba32_checkbutton = xml.get_widget("lba32_checkbutton")


        self.grub_password_label = xml.get_widget("grub_password_label")
        self.grub_password_checkbutton = xml.get_widget("grub_password_checkbutton")
        self.grub_password_hbox = xml.get_widget("grub_password_hbox")
        self.grub_password_entry = xml.get_widget("grub_password_entry")
        self.grub_password_confirm = xml.get_widget("grub_password_confirm")
        self.grub_password_encrypt_checkbutton = xml.get_widget("grub_password_encrypt_checkbutton")
        self.bootloader_vbox = xml.get_widget("bootloader_vbox")
        self.vbox33 = xml.get_widget("vbox33")
        self.parameter_hbox = xml.get_widget("parameter_hbox")
        self.parameters_entry = xml.get_widget("parameters_entry")
        self.parameters_checkbutton = xml.get_widget("parameters_checkbutton")
        self.parameters_entry.connect("changed",self.toggled_parameters)
        self.menuentry_enable_checkbutton = xml.get_widget("menuentry_enable_checkbutton")
        self.menuentry_entry = xml.get_widget("menuentry_entry")
# Connect 3 grub buttons with toggled_bootloader
        self.grub_password_checkbutton.connect("toggled", self.toggled_grub_password)
        self.upgrade_bootloader_radio.connect("toggled",self.toggled_bootloader)
        self.firstsector_radiobutton.connect("toggled",self.toggled_bootloader)
        self.grub_mbr_radiobutton.connect("toggled",self.toggled_bootloader)
        self.no_bootloader_radio.connect("toggled", self.toggled_nobootloader)
        self.lilo_radiobutton.connect("toggled", self.toggled_lilo)

# Install GRUB by default
        self.grub_mbr_radiobutton.set_active(True)
        self.grub_password_encrypt_checkbutton.set_active(True)

    def toggled_parameters(self,args):
        self.parameters_checkbutton.set_active(True)

    def toggled_bootloader (self, args):
        status = self.firstsector_radiobutton.get_active() or self.grub_mbr_radiobutton.get_active() or self.upgrade_bootloader_radio.get_active()
        self.grub_password_checkbutton.set_sensitive(status)
        self.menuentry_enable_checkbutton.set_sensitive(status)
        self.menuentry_entry.set_sensitive(status)

    def toggled_grub_password(self, args):
        status = self.upgrade_bootloader_radio.get_active() or self.firstsector_radiobutton.get_active() or self.grub_mbr_radiobutton.get_active()
        self.grub_password_hbox.set_sensitive(self.grub_password_checkbutton.get_active())

    def toggled_nobootloader(self,args):
        self.parameter_hbox.set_sensitive(not self.no_bootloader_radio.get_active())
        self.grub_password_hbox.set_sensitive(not self.no_bootloader_radio.get_active())
        self.grub_password_checkbutton.set_sensitive(not self.no_bootloader_radio.get_active())

    def toggled_lilo(self,args):
        self.grub_password_hbox.set_sensitive(not self.lilo_radiobutton.get_active())
        self.grub_password_checkbutton.set_sensitive(not self.lilo_radiobutton.get_active())

    def platformTypeChanged(self, platform):
        if platform != "x86" and platform != "AMD64 or Intel EM64T":
            self.vbox33.hide()
#            self.bootloader_vbox.hide()
            self.bootloader_label.set_text(_("Bootloader options are not applicable to "
                                             "the %s platform" % platform))
            self.bootloader_label.show()
        else:
            self.vbox33.show()
#            self.bootloader_vbox.show()
            self.bootloader_label.hide()

#    def enableUpgradeRadio(self, boolean):
#        self.upgrade_bootloader_radio.set_sensitive(not boolean)

#    def grub_pw_changed(self,args):
#        self.grub_bootloader_radio.set_active(True)

    def getData (self):
        buf = ""
# No bootloader will be installed
        if self.no_bootloader_radio.get_active():
            buf = buf + "d-i grub-installer/skip boolean true" + "\nd-i lilo-installer/skip boolean true"
# LILO bootloader will be installed
        elif self.lilo_radiobutton.get_active():
            buf = buf + "d-i grub-installer/skip boolean true" + "\nd-i lilo-installer/skip boolean false"
# GRUB will be installed
        else :

            if self.grub_mbr_radiobutton.get_active():
                buf = buf + "d-i grub-installer/only_debian boolean true" + "\nd-i grub-installer/with_other_os boolean true"
            elif self.firstsector_radiobutton.get_active():
                buf = buf + "d-i grub-installer/only_debian boolean false" + "\nd-i grub-installer/with_other_os boolean false" + "\nd-i grub-installer/bootdev  string (hd0,1)"
            elif self.upgrade_bootloader_radio.get_active():
                buf = buf + "d-i grub-installer/with_other_os boolean true"


#GRUB Password
            if (self.grub_password_checkbutton.get_active() == True) and (not self.lilo_radiobutton.get_active()):
                gp = string.strip (self.grub_password_entry.get_text())
                cp = string.strip (self.grub_password_confirm.get_text())
                length = len(gp)
                if length > 0:
                    if gp == cp:
                        if self.grub_password_encrypt_checkbutton.get_active():
                            salt = "$1$"
                            saltLen = 8
                            for i in range(saltLen):
                                salt = salt + random.choice (string.letters + string.digits + './')
                            self.passwd = crypt.crypt (gp, salt)
                            temp = unicode (self.passwd, 'iso-8859-1')
                            buf = buf + "\nd-i grub-installer/password-crypted password " + temp
                        else:
                            buf = buf + "\nd-i grub-installer/password password " + gp + "\nd-i grub-installer/password-again password " + gp

                    else:
                        dlg = gtk.MessageDialog(None, 0, gtk.MESSAGE_WARNING, gtk.BUTTONS_OK,
                                                (_("Grub passwords do not match.  Please try again.")))
                        dlg.set_position(gtk.WIN_POS_CENTER)
                        dlg.set_modal(True)
                        dlg.set_icon(kickstartGui.iconPixbuf)
                        dlg.run()
                        dlg.destroy()
                        self.grub_password_entry.set_text("")
                        self.grub_password_confirm.set_text("")
                        self.notebook.set_current_page(2)
                        self.grub_password_entry.grab_focus()
                        return None
            if self.parameters_checkbutton.get_active():
                buf = buf + "\nd-i debian-installer/add-kernel-opts string " + self.parameters_entry.get_text()

        self.kickstartData.setBootloader([buf])
        return 0

    def fillData(self):
        list = self.kickstartData.getBootloader()

        if list == None:
            return

        for item in list:
            if item[:11] == "":
                if item[11:] == "d-i grub-installer/skip boolean true":
                    self.no_bootloader_radio.set_active(True)
                elif item[11:] == "mbr":
                    self.grub_mbr_radiobutton.set_active(True)
                elif item[11:] == "partition":
                    self.firstsector_radiobutton.set_active(True)
                elif item[11:] == "d-i lilo-installer/skip boolean true #liloooooooooooooooooooo":
                    self.lilo_radiobutton.set_active(True)

            if item[:10] == "/password":
                self.grub_password_entry.set_text(item[10:])
                self.grub_password_confirm.set_text(item[10:])

        if "--append" in list:
            self.parameters_entry.set_text(list[list.index(item)])

        if "--md5pass" in list:
            self.grub_password_encrypt_checkbutton.set_active(True)

        if "--upgrade" in list:
            self.upgrade_bootloader_radio.set_active(True)

